package com.suning.epa_plugin.utils

import android.app.Activity
import android.content.Context
import android.text.TextUtils
import com.suning.epa_plugin.BuildConfig
import com.suning.epa_plugin.EPAFusionInfoUtil
import com.suning.epa_plugin.auth.RealNameAuthUtil
import com.suning.epa_plugin.bankcardmanager.BankCardProxy
import com.suning.epa_plugin.config.StrsContents
import com.suning.epa_plugin.net.VolleyRequestController
import com.suning.epa_plugin.retrievePayPwd.PayPwdManagerUtils
import com.suning.epa_plugin.trust_login.LoginController
import com.suning.epa_plugin.utils.custom_view.EbuyDependMethond
import com.suning.epa_plugin.webview.EfwProxy
import com.suning.mobile.epa.kits.common.SourceConfig
import com.suning.mobile.epa.kits.utils.LogUtils
import com.suning.mobile.epa.mpc.MpcUtil

/**
 * @Author 17033098
 * @Date 2019/10/8 10:27
 * @Description
 */
object MetroCodeUtil {

    /**
     * 易购小店入口解析规则
     * adId = "0",码页面
     * adId = "1",乘车记录
     * adId = "2_1111111",下划线后面的是订单号
     * adId = "3_025_1",第一个下划线后面是城市编号cityno,第二个下划线后面是tripType
     */
    fun resolveParams(id: String): HashMap<String, String> {
        val params = java.util.HashMap<String, String>()
        if (BuildConfig.IS_FOR_PPTV) {
            return params
        }
        if (!TextUtils.isEmpty(id)) {
            if (id.startsWith("0") || id.startsWith("1")) {
                params["orderNum"] = id
            } else if (id.startsWith("2") && id.contains("_")) {
                //解析出订单号
                val tmps = id.split("_")
                if (tmps.size >= 2) {
                    params["orderNum"] = tmps[1]
                } else {
                    //参数不符合规则,不传参数
                }
            } else if (id.startsWith("3") && id.contains("_")) {
                //解析出cityNo, tripType
                val tmps = id.split("_")
                if (tmps.size >= 3) {
                    params["cityNo"] = tmps[1]
                    params["tripType"] = tmps[2]
                } else {
                    //参数不符合规则,不传参数
                }
            }
        }
        return params
    }

    fun start(context: Context, id: String) {
        if (BuildConfig.IS_FOR_PPTV) {
            return
        }
        initContext(context)
        startMetroCode(context, id)
    }

    fun start(context: Context, map: HashMap<String, String>) {
        if (BuildConfig.IS_FOR_PPTV) {
            return
        }
        initContext(context)
        startMetroCode(context, map)
    }

    private fun initContext(context: Context) {
        val loginId = EbuyDependMethond.getLatestAccount()
        if (LoginController.nowLoginId != loginId) {
            AccountUtils.clearUserBean()
            LoginController.nowLoginId = loginId
            LoginController.isEPALogin = false
        }
//        EpaKitsApplication.setContext(activity.application)
//        NetKitApplication.getInstance().setContext(activity.application)
    }

    private fun getMpcBuilder(context: Context) {
        var channel = MpcUtil.MpcChannelType.MpcChannelRH
        if (EPAFusionInfoUtil.getSourceType() == "SNStore") {
            channel = MpcUtil.MpcChannelType.MpcChannelRHXD
        }
        MpcUtil.builder.setAppId("12000")
                .setVersion(StrsContents.PLUGIN_VERSION)
                .setSource(SourceConfig.SourceType.SN_ANDROID)
                .setChannel(channel)
                .setCookieStore(VolleyRequestController.getInstance().getCookieStore())
                .setH5CallBack(object : MpcUtil.MpcH5CallBack {
                    override fun gotoH5WebVIew(context: Context, url: String) {
                        EfwProxy.start(context, url)
                    }
                })
                .setMpcCodeListener(object : MpcUtil.MpcCodeListener {
                    override fun setPayPwd(activity: Activity, isReset: Boolean, callBack: (Boolean, String) -> Unit) {
                        PayPwdManagerUtils.gotoPayPwdSDK(activity, "1009", { isSuccess, msg -> callBack(isSuccess, msg) }, isReset)
                    }

                    override fun toAddBankCard(activity: Activity, callBack: (Boolean, String) -> Unit) {
                        BankCardProxy.goAddBankCardH5WithSource(activity, "1009") { isSuccess, msg ->
                            callBack(isSuccess, msg)
                        }
                    }

                    override fun toPrimaryRealName(activity: Activity, callBack: (Boolean, String) -> Unit) {
                        RealNameAuthUtil.gotoPrimaryRealAuth(activity, "1009") { isSucceed, msg -> callBack(isSucceed, msg) }
                    }

                    override fun checkLoginStatus(): Boolean {
                        return LoginController.isEPALogin
                    }
                })
                .setNeedLogon(object : MpcUtil.MpcAutoLogon {
                    override fun autoLogon(callBack: MpcUtil.MpcNeedLogonCallBack) {
                        LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon Deprecated.")
                        val listener = LoginController.OnLoginListener { isSuccess ->
                            LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon(no context) OnLoginListener isSuccess = ", isSuccess.toString())

                            callBack.onSuccess(isSuccess)
                        }
                        if (EbuyDependMethond.isEbuyLogon()) {
                            LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon(no context) toTrustLogin.")

                            LoginController.getInstance().addOnLoginListener(listener)
                            LoginController.getInstance().toTrustLogin(context)
                        } else {
                            LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon(no context) callExternalLogin.")
                            EPAFusionInfoUtil.getEpaListener().callExternalLogin { isLogin ->
                                if (isLogin) {
                                    LoginController.getInstance().addOnLoginListener(listener)
                                    LoginController.getInstance().toTrustLogin(context)
                                }
                            }
                        }
                    }

                    override fun autoLogon(context: Context, callBack: MpcUtil.MpcNeedLogonCallBack) {
                        LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon.")
                        val listener = LoginController.OnLoginListener { isSuccess ->
                            LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon(has context) OnLoginListener isSuccess = ", isSuccess.toString())

                            callBack.onSuccess(isSuccess)
                        }
                        if (EbuyDependMethond.isEbuyLogon()) {
                            LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon(has context) toTrustLogin.")

                            LoginController.getInstance().addOnLoginListener(listener)
                            LoginController.getInstance().toTrustLogin(context)
                        } else {
                            LogUtils.d("SnfPlugin >> MpcUtil.MpcAutoLogon autoLogon(has context) callExternalLogin.")
                            EPAFusionInfoUtil.getEpaListener().callExternalLogin { isLogin ->
                                if (isLogin) {
                                    LoginController.getInstance().addOnLoginListener(listener)
                                    LoginController.getInstance().toTrustLogin(context)
                                }
                            }
                        }
                    }
                })
    }

    private fun startMetroCode(context: Context, id: String) {
        getMpcBuilder(context)
        MpcUtil.builder.start(context, id)
    }

    private fun startMetroCode(context: Context, map: HashMap<String, String>) {
        getMpcBuilder(context)
        MpcUtil.builder.start(context, map)
    }
}
